# denki-client
Python client to retreive data from Entsoe API.

Inspired by [entsoe-py](https://github.com/EnergieID/entsoe-py) repository.

## Features
- asynchronous client
- agnostic DataFrame library

## Dev
To debug the client:
```py
import logging

logging.basicConfig(level=logging.DEBUG)
```
